@@ -7,9 +7,9 @@ class atasozu:
     # Atasözünün ön takısını str olarak döndürür.
     # Returns the prefix of the adage as str.
     def ontaki(self):
-        return self.ontaki
+        return self.onTaki
 
     # Atasözünün kendisini str olarak döndürür.
     # Returns the adage itself as str.
     def atasozu(self):
-        return self.icerik
\ No newline at end of file
+        return self.icerik
